* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [AI Governance](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption)
  * Step 2: Assess AI Potential and Usage
